# -*- coding: utf-8 -*-
# !/usr/bin/python
# Create Date 2017/9/29 0029
import os
import json
import xlrd
import chardet
from demo_xml import demo_xml
try:
    import csv
except:
    pass
__author__ = 'huohuo'
if __name__ == "__main__":
    pass


class File:

    def __init__(self, base_dir=''):
        self.__description__ = '文件相关， 包括读文件，写文件， 下载文件'
        self.base_dir = base_dir

    def read(self, file_name, sheet_name='Sheet1', read_type='r', dict_name='', to_json=True, table_sheet=True, **kwargs):
        file_type = file_name.split('.')[-1]
        url = os.path.join(self.base_dir, dict_name, file_name)
        if os.path.exists(url) is False:
            print 'File not exists, %s. Please check.' % url
            return None
        to_string = kwargs.get('to_string')
        if file_type in ['xlsx', 'xls']:
            table_sheet = kwargs.get('table_sheet')
            data = xlrd.open_workbook(url)
            table = data.sheet_by_name(sheet_name)
            if table_sheet:
                return table
            items = []
            ths = table.row_values(0)
            strings = '\t'.join(ths)
            items1 = [ths]
            nrow = table.nrows
            for i in range(1, nrow):
                item1 = []
                item = {}
                for j in range(0, len(ths)):
                    cell = table.cell_value(i, j)
                    item[ths[j]] = cell
                    item1.append(cell)
                if to_string:
                    strings += '\n%s' % ('\t'.join(item1))
                items.append(item)
                items1.append(item1)
            if to_string:
                return strings.strip('\n')
            if to_json:
                return items
            return items1
        f = open(url, read_type)
        text = f.read()
        f.close()
        if not to_string:
            if file_type in ['csv', 'tsv'] or 'sep' in kwargs:
                encoding = chardet.detect(text)['encoding']
                sep = ',' if file_type == 'csv' else '\t'
                if 'sep' in kwargs:
                    sep = kwargs['sep']
                delimiter = {'delimiter': sep}
                f = open(url, read_type)
                # csv.register_dialect('my_dialect', **delimiter)
                cons = csv.reader(f, **delimiter)
                items = []
                keys = next(cons)
                for c in cons:
                    if to_json:
                        item = {}
                        for i in range(len(keys)):
                            k = keys[i].decode(encoding).encode('utf-8')
                            item[k] = c[i].decode(encoding).encode('utf-8')
                        items.append(item)
                    else:
                        items.append([x.decode(encoding).encode('utf-8') for x in c])
                # csv.unregister_dialect('my_dialect')
                if to_json is False:
                    items = [keys] + items
                return items
            if file_type == 'json':
                return json.loads(text)
        return text

    def read_message(self, file_name, file_type='json', sheet_name='', read_type='r', developer='huohuo', message='success'):
        error_message = u'【开发者】：%s\n' % developer
        error_message += u'【文件类型】：%s\n' % file_type
        if file_type in ['xlsx', 'xls']:
            error_message += u'【sheet_name】：%s\n' % sheet_name
        error_message += u'【消息】：%s\n' % message
        error_message += u'【文件名】：\n%s\n' % file_name

    def write(self, file_name, data):
        file_type = file_name.split('.')[-1]
        url = os.path.join(self.base_dir, file_name)
        f = open(url, "w")
        if file_type == 'json':
            try:
                f.write(json.dumps(data, sort_keys=True, indent=4, ensure_ascii=False))
            except:
                f.write(json.dumps(data, sort_keys=True, indent=4, ensure_ascii=True))
        else:
            f.write(data)
        f.close()
        return 5

    def download(self, pkg_parts, file_name):
        temp_data = demo_xml.replace('<pkg:part id="pkg_parts"></pkg:part>', pkg_parts)
        temp_data = temp_data.replace('\n', '')
        return self.write(file_name, temp_data)

    def get_file_list(self, file_type, pre='', postfix=None):
        file_list = []
        folder_list = []
        full_path = os.path.join(self.base_dir, pre)
        for file_name in os.listdir(full_path):
            path_file = os.path.join(full_path, file_name)
            file_dict = {
                'file_name': file_name,
                'url': path_file,
                'dir_path': os.path.dirname(path_file),
                'full_path': file_name,
                'relative_path': os.path.relpath(path_file, self.base_dir)
            }
            if os.path.isdir(path_file):
                folder_list.append(file_dict)
            elif os.path.isfile(path_file):
                file_dict["type"] = file_type
                file_dict['file_size'] = self.get_file_size(path_file)
                is_selected = self.is_selected(file_name, postfix)
                file_dict['is_selected'] = is_selected
                if is_selected:
                    file_list.append(file_dict)
        folder_list.sort()
        file_list.sort()
        return {'data': {'folder': folder_list, 'file': file_list}}

    def get_file_size(self, path_file):
        try:
            size = os.path.getsize(path_file)
        except Exception, e:
            return '未知'
        if size > 1024 ** 3:
            return '%.02fGB' % (float(size) / 1024 ** 3)
        elif size > 1024 ** 2:
            return '%.02fMB' % (float(size) / 1024 ** 2)
        elif size > 1024:
            return '%0.2fKB' % (float(size) / 1024)
        else:
            return '%0.2fB' % (float(size))

    def get_file_item(self, file_name, path_file):
        return {
            'file_name': file_name,
            'url': path_file,
            'dir_path': os.path.dirname(path_file),
            'full_path': file_name,
            'relative_path': os.path.relpath(path_file, self.base_dir)
        }

    def is_selected(self, file_name, postfix=None):
        if postfix is None:
            return True
        for p in postfix:
            if file_name.endswith(p):
                return True
        return False


# -*- coding: utf-8 -*-
# !/usr/bin/python
# Create Date 2019/4/1 0001
__author__ = 'huohuo'

import os
import socket
import requests
import logging
from Web2 import login_manager, blues
from Class.JY_config import env, env_name, session_cookie_domain, debug, system_config, footer_config, \
    register_phone, API_service_JYAUTH, API_service, JYConfig, refresh_footer
from flask import request, g, render_template, redirect, session, Flask
from flask_login import current_user
from Class.common import Common, JYRequestsException
from Class.jinja_filter import MyJinja
from Class.flask_wraps import del_session

try:
    from flask_wtf.csrf import CSRFProtect
except Exception, e:
    from flask_wtf.csrf import CsrfProtect as CSRFProtect
from Class.dingding_message_tool import send_msg_by_dd

"""
# File Name: create_app.py
# Description: create system app for web.
"""
common = Common()
Jinja = MyJinja()
csrf = CSRFProtect()
jyc = JYConfig()


def create_app():
    app = Flask(__name__)
    sys_config_dict = {
        "env": env,
        "setting_name": "", "system_name": "",
        "logo_url": "", "log_info": "",
        "module_config": {},
        "footer_setting": {},
        "db_config_dict": {},
        "system_api_host_setting": {}
    }
    for item in sys_config_dict:
        app.config[item] = ""
    app.config["JINGDU_DB_SETTING"] = ""
    app.config["validate_ttf_path"] = "%s/flask_tools/huawenxinsong.ttf" % app.root_path
    app.config["validate_code_setting"] = {
        "path": "%s/flask_tools/huawenxinsong.ttf" % app.root_path,
        "background_color": "#ffffff", "word_count": 4,
        "draw_lines": False, "draw_points": False,
        "fg_color": "black", "font_size": 16,
        "width": 140, "height": 30
    }
    app.config["access_token"] = "6758503db71f223cf23fd0251d6fd07ef58ad5ceaeb3e06204440a324a97f5ef"
    app.config["LOGIN_DISABLED"] = True
    # 默认前端通知
    if session_cookie_domain != "":
        app.config["SESSION_COOKIE_DOMAIN"] = session_cookie_domain
    app.secret_key = 'a string'
    login_manager.init_app(app)

    system_module_dict = jyc.module_config  #
    # get_system_module()
    for module_name in system_module_dict:
        module_load_flag = system_module_dict[module_name]
        if module_load_flag in ["true", 'True', True]:
            # print app.root_path
            web_files = os.listdir("%s/views/%s" % (app.root_path, module_name))
            # print web_files
            for web_file in web_files:
                if web_file != "__init__.py":
                    if web_file.endswith(".py"):
                        __import__("Web2.views.%s.%s" % (module_name, web_file[:-3]))

    if "Development" in env:
        __import__("Web2.views.test.auth_test")
    for key, value in blues.items():
        if len(value[1]) > 1:
            app.register_blueprint(value[0], url_prefix=value[1])
        else:
            app.register_blueprint(value[0])

    @app.context_processor
    def context_processor():
        """
        系统级别的变量
        :return:
        """

        host = request.host
        system_debug = app.config["DEBUG"]

        env = system_config["env"]
        log_info = eval(system_config["log_info"])
        system_name = system_config["system_name"]
        url = request.args.get('company_info_url')
        if url is not None and os.path.exists(url):
            os.environ['company_info_url'] = url
            refresh_footer(url)
        logo_login_url = system_config["logo_login_url"]
        logo_url = system_config["logo_url"]
        system_module = jyc.module_config
        account = '' if not hasattr(current_user, 'account') else current_user.account
        base_host = "http://%s" % host

        return {"env": env, 'env_name': env_name,
                "register_phone": register_phone,
                "sys_account": account, "system_debug": system_debug,
                "host": host, "log_info": log_info,  "base_host": base_host, "debug": system_debug,
                "logo_url": logo_url, "logo_login_url": logo_login_url,
                "footer_config_dict": footer_config,
                "system_module": system_module,
                "system_name": system_name}

    @app.errorhandler(500)
    def handlers_500(error):
        """
        500 错误，钉钉通知，session 中必须存在 mobile_phone 参数
        session 中 dingding_module，machine_man 两个参数需一起存在，方可选择制定群通知
        :param error:
        :return:
        """
        error_status = 100
        error_num = 1003
        error_info = '' if not hasattr(error, 'message') else error.message
        status = '' if not hasattr(error, 'status') else error.status
        try:
            account = current_user.account
        except Exception, e:
            logging.warn(e.args)
            account = ""
        error_message = "!!500错误!!\n"
        if account:
            error_message += "\n【用户名】：%s\n" % (account)
        error_info = '%s: %s' % (str(type(error)), str(error_info))
        error_message += "【路径】: %s\n【请求方式】: %s\n" % (request.url, request.method)
        error_message += "【错误信息】: %s\n" % error_info
        send_msg_by_dd(error_message)
        return '网络异常，已通知管理员维修，请稍后重试'

    @app.before_request
    def before_request():

        my_headers = {}
        if "X-Forwarded-For" in request.headers:
            my_headers["X-Forwarded-For"] = request.headers["X-Forwarded-For"] + "," + request.remote_addr
        else:
            my_headers["X-Forwarded-For"] = request.remote_addr
        if "sample_token_ams" in request.args:
            sample_token_ams = request.args['sample_token_ams']
            my_headers['sample_token_ams'] = request.args['sample_token_ams']
            if 'sample_token_ams' in session:
                del session['sample_token_ams']
            session['sample_token_ams'] = sample_token_ams
        if env == "Development":
            if "login_disabled" in session:
                my_headers["X-Skip-Auth"] = session["login_disabled"]
        g.user_name = session.get('user_name')
        g.requests = requests.session()
        g.requests.headers = my_headers
        if current_user.is_authenticated:
            try:
                g.requests.auth = current_user.auth
            except AttributeError, e:
                logging.error(e.message)

    @app.after_request
    def after_request(res):
        if res.status_code == 302 or res.status_code == 301:
            if "X-Request-Protocol" in request.headers:
                pro = request.headers["X-Request-Protocol"]
                if "Location" in res.headers:
                    location = res.headers["location"]
                    if location.startswith("http:"):
                        res.headers["Location"] = pro + ":" + res.headers["Location"][5:]
                    elif location.startswith("/"):
                        res.headers["Location"] = "%s://%s%s" % (pro, request.headers["Host"], location)
        return res

    csrf.init_app(app)
    Jinja.filter(app)
    app.jinja_env.add_extension('jinja2.ext.loopcontrols')

    app.debug = debug
    # set a 'SECRET_KEY' to enable the Flask session cookies
    app.config['SECRET_KEY'] = 'GATC SECRET_KEY SDFSDF234234SDF342?>:K;SDK'
    return app
    




# -*- coding: utf-8 -*-
# !/usr/bin/python
# Create Date 2019/5/28 0028
__author__ = 'huohuo'
from jy_word.File import File
from jy_word.web_tool import format_time
import uuid
my_file = File()


# def get_uuid():
#     uid = uuid.uuid1().hex
#     return uid
#
#
# templates = my_file.read('tcm_template.json')
# # print d
# templates1 = []
# for template in templates:
#     blocks = template.get('items') or []
#     template['template'] = get_uuid()
#     blocks2 = []
#     for block in blocks:
#         bb = block.get('items') or []
#         block['entry_name'] = block['title']
#         del block['title']
#         block['block_id'] = get_uuid()
#         bb1 = []
#         for item in bb:
#             print item.keys(), item.get('text')
#             input_items = item.get('input_items') or []
#             for ii in input_items:
#                 # print ii.keys()
#                 uid = get_uuid()
#                 ii['item_id'] = uid
#                 ii['item_name'] = ii.get('label')
#                 if 'field' in ii:
#                     ii['field'] = ii['item_id']
#                 # elif ii.get('is_group'):
#                 #     group = ii.get('is_group')
#                 #     print ii
#                 elif 'items' in ii:
#                     group = ii.get('is_group')
#                     items = ii.get('items')
#                     for iiii, iii in enumerate(items):
#                         if 'field' in ii:
#                             iii['field'] = get_uuid()
#                         elif group:
#                             iii['field'] = '%s%s' % (uid, iiii)
#                         else:
#                             print iii
#                 elif ii.get('is_list'):
#                     data = ii.get('data')
#                     ids = []
#                     for datai in range(len(data)):
#                         ids.append('%s%s' % (uid, datai))
#                     ii['uuids'] = ids
#                 else:
#                     print ii.keys()
#                 # for k in ii:
#                 #     if (type(ii[k])) not in ['unicode', 'str']:
#                 #         ii[k] = json.dumps(ii[k])
#             bb11 = {'items': input_items, 'entry_name': item.get('text'), 'block_id': get_uuid()}
#             for k in item.keys():
#                 if k not in bb11:
#                     bb11[k] = item[k]
#             bb1.append(bb11)
#         blocks2.append(bb1)
#     templates1.append(blocks2)
#
#
# # my_file.write('tcm_template1.json', templates)
# import requests
# import easygui as eg
# from requests.auth import HTTPBasicAuth
#
# auth = HTTPBasicAuth('hpp_test', 'hpp.123456')
# headers = {'Content-Type': 'application/json'}
# print auth.username
# rq_template = get_uuid()
# template_name = '普适版%s' % format_time(frm='%m%d%H%M')
# template_name = eg.enterbox('模板标题', default=template_name)
#

rq_data = my_file.read('tcm_template_online.json')[0]
template_info = rq_data.get('template_info')
template_info1 = []
for tem in template_info:
    new_tem = [ ]
    for block in tem:

        items = block.get('items')
        items_info = []
        for item in items:
            display_control_item = {}
            for k2 in item.keys():
                if k2 not in ['item_name', 'item_id', 'description']:
                    display_control_item[k2] = item[k2]
            new_item = {
                'item_name': item.get('item_name'),
                'item_id': item.get('item_id'),
                'description': item.get('field'),
                'display_control': display_control_item
            }
            items_info.append(new_item)

        display_control = {}
        for k in block.keys():
            if k not in ['block_id', 'items', 'text', 'input_items', 'entry_name']:
                display_control[k] = block.get(k)
        new_block = {
            'block_name': block.get('entry_name'),
            'block_id': block.get('block_id'),
            'items_info': items_info,
            'description': block.get('text') or '',
            'display_control': display_control
        }
        new_tem.append(new_block)
    template_info1.append(new_tem)

my_file.write('template_online_new.json', template_info1)

if __name__ == "__main__":
    pass
    




# -*- coding: utf-8 -*-
# !/usr/bin/python
# Create Date 2019/1/25 0025
__author__ = 'huohuo'

import requests
from aip import AipOcr
import sys
reload(sys)
sys.setdefaultencoding('utf8')
APP_ID = '15486076'
API_KEY = 'cNnOpI7tSp0fOkSCRIprx4US'
SECRET_KEY = '5MIuHdx02gs2bDVtDgOwzA8lXRIEobm3'
template_id = '75728a7d5fbaa201049f6198f651305f'
# client_id 为官网获取的AK， client_secret 为官网获取的SK

client = AipOcr('15486462', 'vzYWYRTiZA6pzmQePdFw1rs1', 'ZUWT9fFedej78rLPngN1yfCCLz7I4Mxj')


def get_file_content(filePath):
    with open(filePath, 'rb') as fp:
        return fp.read()


def print_result(result):
    for r in result:
        for k in r:
            print r[k], '\t',
        print '\n'


def my_rq(method, url, params=None, rq=None, headers=None):
    if headers is None:
        headers = {'Content-Type': 'application/json; charset=UTF-8'}
    res = requests.request(method, url, params=params, headers=headers, json=rq)
    if res.status_code == 200:
        return res.json()
    return None


def get_access_token():
    params = {'grant_type': 'client_credentials', 'client_id': API_KEY, 'client_secret': SECRET_KEY}
    rq = my_rq('POST', 'https://aip.baidubce.com/oauth/2.0/token', params=params)
    if rq:
        return rq['access_token']
    return None


def get_img(img):
    access_token = get_access_token()
    if access_token is None:
        return None
    print access_token
    params = {'access_token': access_token}
    headers = {'Content-type': 'application/x-www-form-urlencoded'}
    rq = {'image': img, 'templateSign': '75728a7d5fbaa201049f6198f651305f2019'}
    res = requests.request('POST', 'https://aip.baidubce.com/rest/2.0/solution/v1/iocr/recognise',
                params=params, headers=headers, data=rq)
    if res:
        print res.json()
    return None


image = get_file_content('test_aip.jpg')
data0 = client.basicAccurate(image)
print_result(data0['words_result'])
# get_img(image)
from jy_word.File import File
my_file = File()
data1 = client.custom(image, template_id)
# print data1
my_file.write('aip_test.json', data1)

if __name__ == "__main__":
    pass
    




# -*- coding: utf-8 -*-
# !/usr/bin/python
# Create Date 2019/2/18 0018
__author__ = 'huohuo'
import datetime
import hashlib
import requests
import random
import sys
import time
import urllib
import xml.etree.ElementTree as ET

reload(sys)
sys.setdefaultencoding('utf-8')


#处理函数，对参数按照key=value的格式，并按照参数名ASCII字典序排序
def format_rq(obj):
    return '&'.join(["{0}={1}".format(k, obj.get(k))for k in sorted(obj)])


# 对字符串进行MD5加密
def str2md5(text, text_unicode='utf-8'):
    return hashlib.md5(text.encode(text_unicode)).hexdigest()


#根据当前系统时间来生成商品订单号。时间精确到微秒
def getWxPayOrdrID():
    date = datetime.datetime.now()
    #根据当前系统时间来生成商品订单号。时间精确到微秒
    payOrdrID=date.strftime("%Y%m%d%H%M%S%f")
    return payOrdrID


# 生成随机字符串
def getNonceStr(length=30):
    data = "123456789zxcvbnmasdfghjklqwertyuiopZXCVBNMASDFGHJKLQWERTYUIOP"
    nonce_str = ''.join(random.sample(data, length))
    return nonce_str


def xml_to_dict(xml_data):
    '''
    xml to dict
    :param xml_data:
    :return:
    '''
    xml_dict = {}
    root = ET.fromstring(xml_data)
    for child in root:
        xml_dict[child.tag] = child.text
    return xml_dict


def dict_to_xml(dict_data):
    '''
    dict to xml
    :param dict_data:
    :return:
    '''
    xml = ["<xml>"]
    for k, v in dict_data.iteritems():
        xml.append("<{0}>{1}</{0}>".format(k, v))
    xml.append("</xml>")
    return "".join(xml)


class JYWXPAY:

    def __init__(self, app_id, Mch_id, Mch_key):
        self.app_id = app_id
        self.Mch_id = Mch_id
        self.Mch_key = Mch_key

    # 生成签名(微信)
    def format_sign(self, obj):
        stringSignTemp = '{0}&key={1}'.format(format_rq(obj), self.Mch_key)
        return str2md5(stringSignTemp).upper()

    def wx_request(self, action, order_info):
        url = 'https://api.mch.weixin.qq.com/pay/%s' % action
        order_info['appid'] = self.app_id
        order_info['mch_id'] = self.Mch_id
        order_info['nonce_str'] = getNonceStr()
        order_info['sign'] = self.format_sign(order_info) #获取签名
        body_data = dict_to_xml(order_info)  # 拿到封装好的xml数据
        #请求微信接口下单
        respone = requests.post(url, body_data.encode("utf-8"), headers={'Content-Type': 'application/xml'})
        #回复数据为xml,将其转为字典
        return xml_to_dict(respone.content)

    # 微信支付统一下单
    def get_wx_order(self, order_info):
        price = order_info.get('total_amount')
        order_info = {
            "body": order_info.get('subject'),#商品描述
            "notify_url": order_info.get('notify_url'), #支付成功的回调地址
            "openid": order_info.get('openid'), #用户标识
            "out_trade_no": order_info.get('out_trade_no'), #商户订单号
            "spbill_create_ip": order_info.get('cip'),  #客户端终端 request.remote_addr
            "total_fee": str(int((float(price) * 100))),   #总金额 单位为分
            "trade_type": 'JSAPI'  #交易类型 小程序取值如下：JSAPI
        }
        content = self.wx_request('unifiedorder', order_info)
        if content["return_code"] == 'SUCCESS':
            data = {
                'appId': self.app_id,
                'nonceStr': content.get("nonce_str"), # 获取随机字符串
                'package': "prepay_id="+content.get("prepay_id"), # 获取预支付交易会话标识
                'signType': 'MD5',
                'timeStamp': str(int(time.time()))
            }
            #获取paySign签名，这个需要我们根据拿到的prepay_id和nonceStr进行计算签名
            data['paySign'] = self.format_sign(data)
            # 封装返回给前端的数据
            return {'status': 4000001, 'message': 'success', 'data': data}
        return {'status': content.get('return_code'), 'message': content.get('return_msg')}

    # 根据商品订单号查询微信付款情况
    def query_order(self, out_trade_no):
        order_info = {"out_trade_no": out_trade_no}
        content = self.wx_request('orderquery', order_info)
        total_fee = content.get('total_fee')
        if total_fee is not None:
            content['total_amount'] = '%.02f' % (float(total_fee) / 100)
        pay_time = content.get('time_end')
        if pay_time is not None:
            content['pay_time'] = pay_time
        status = content.get('trade_state')
        msg = content.get('trade_state_desc')
        if msg is None:
            msg = content.get('return_msg')
        # print status, msg
        return {'status': status, 'message': msg, 'order_info': content}


class JYWX:

    def __init__(self, app_id, app_secret):
        self.app_id = app_id
        self.app_secret = app_secret
        self.gateway = 'https://api.weixin.qq.com/cgi-bin/'

    def wx_request(self, method, action, params=None, json=None, headers=None):
        if headers is None:
            headers = {'Content-Type': 'application/json'}
        res = requests.request(method, '%s%s' % (self.gateway, action), params=params, json=json, headers=headers)
        if res.status_code == 200:
            return res.json()
        return None


    def get_token(self):
        rq = {'grant_type': 'client_credential', 'appid': self.app_id, 'secret': self.app_secret}
        return self.wx_request('GET', 'token', params=rq)

    def send_msg(self):
        token = self.get_token().get('access_token')
        rq = {
            "touser": "ochiws76uvCapRK11chSqJxp5nZM",
            "msgtype": 'text',
            "text": {"content": 'hello xiaohuo'}
        }
        if token is not None:
            return self.wx_request('POST', 'message/custom/send?access_token=%s' % token, json=rq)
        return None


# ===================支付宝==================
try:
    from alipay import AliPay
except:
    print 'pip install python-alipay-sdk'


class JYALIPAY:

    def __init__(self, ALIPAY_APPID, app_private_key_string, alipay_public_key_string, debug=False):
        self.alipay = AliPay(
            appid=ALIPAY_APPID,
            app_notify_url=None,  # 默认回调url
            app_private_key_string=app_private_key_string,
            alipay_public_key_string=alipay_public_key_string,
            # 支付宝的公钥，验证支付宝回传消息使用，不是你自己的公钥,
            sign_type="RSA2",  # RSA2,官方推荐，配置公钥的时候能看到
            debug=debug  # 默认False  配合沙箱模式使用
        )

    def get_order(self, order_info):
        # 创建用于进行支付宝支付的工具对象
        # 电脑网站支付，api_alipay_trade_page_pay
        # APP支付， api_alipay_trade_wap_pay
        # 电脑端需要跳转到https://openapi.alipay.com/gateway.do? + order_string
        func = self.alipay.api_alipay_trade_page_pay
        if order_info.get('type') == 'app':
            func = self.alipay.api_alipay_trade_wap_pay
        total_amount = order_info.get('total_amount')
        order_string = func(
            out_trade_no=order_info.get('out_trade_no'),
            total_amount=str(total_amount),  # 将Decimal类型转换为字符串交给支付宝
            subject=order_info.get('subject'),
            return_url=order_info.get('return_url'),
            notify_url=None  # 可选, 不填则使用默认notify url
        )
        # 让用户进行支付的支付宝页面网址
        url = self.alipay._gateway + "?" + order_string
        return {'status': 1, 'message': 'success', 'url': url}

    def query_order(self, out_trade_no):
        # 创建用于进行支付宝支付的工具对象
        # 调用alipay工具查询支付结果
        biz_content = {'out_trade_no': out_trade_no}
        data = self.alipay.build_body("alipay.trade.query", biz_content)
        url = self.alipay._gateway + "?" + self.alipay.sign_data(data)
        while True:
            raw_string = requests.request('GET', url, timeout=15, headers={'Content-Type': 'application/json'})
            response = raw_string.json().get('alipay_trade_query_response')
            trade_status = response.get('trade_status')
            # 判断支付结果
            if trade_status == 'WAIT_BUYER_PAY':
                continue
            else:
                pay_time = response.get('send_pay_date')
                if pay_time is not None:
                    response['pay_time'] = pay_time
                return {"status": trade_status, "message": response.get("trade_status"), 'order_info': response}


# ====================清华支付===========
class JYTSINGHUAPAY:

    def __init__(self, t_partner, t_key):
        self.t_partner = t_partner
        self.t_key = t_key

    def get_url(self, action, rq, is_sign=True):
        # 合作方编号，秘钥
        # 正式请求路由
        rq['t_partner'] = self.t_partner
        if is_sign:
            rq['t_sign'] = str2md5((format_rq(rq) + self.t_key).encode('gbk'))
        return {'url': 'http://zhifu.tsinghua.edu.cn/sfpt/%s?%s' % (action, urllib.urlencode(rq)), 'order_info': rq}

    def get_order(self, t_rq):
        # out_trade_no = rq.get('out_trade_no')
        # t_item = rq.get('t_item')
        # t_business = rq.get('t_business')
        # t_out_trade_no = '%s%s%s%d' % (t_business[:4], t_item, out_trade_no, random.randrange(0, 10))
        # t_rq = {
        #     't_out_trade_no': t_out_trade_no,
        #     't_item': t_item,
        #     't_name': rq.get('subject'),
        #     't_total_fee': rq.get('total_amount'),
        #     't_return_url': '%s/event/success/' % (rq.get('origin').rstrip('/')),
        #     't_pay_type': '2',  # 1手机端支付，2 PC端支付, 目前仅支持传入2
        #     't_datetime': out_trade_no,
        #     't_username': 'user_name',
        # }
        # username = rq.get('account')
        # if username is not None:
        #     t_rq['t_username'] = username
        return self.get_url('requestPayAction!payment.action', t_rq)

    def query_order(self, t_out_trade_no):
        rq = {'t_out_trade_no': t_out_trade_no, 't_version': '1.1'}
        url_info = self.get_url('queryPayAction.action', rq, is_sign=False)
        response = requests.request('GET', url_info.get('url'))
        status = 'FAIL'
        message = 'query order'
        order_info = url_info.get('order_info')
        if response.status_code == 200:
            data = response.json()
            status = str(data.get('err'))
            if status == '0':
                status = 'SUCCESS'
            message = data.get('msg')
            order_info = data.get('detail')
            if isinstance(order_info, dict):
                order_info['t_total_amount'] = order_info.get('t_total_fee')
                order_info['t_pay_time'] = t_out_trade_no.split(order_info.get('t_item'))[1][:14]
        return {'status': status, 'message': message, 'order_info': order_info}

    def down_bill(self, rq):
        # rq = {
        #     't_item': t_item,
        #     't_bill_date': datetime.datetime.now().strftime('%Y%m%d'),
        # }
        url_info = self.get_url('requestBillAction.action', rq)
        res = requests.request('get', url_info.get('url'))
        if res.status_code == 200:
            return res.text
        return url_info


if __name__ == "__main__":
    # # print str2md5('bdcbdc19871212')
    # # print query_wxorder('20190221164954776532')
    # # print query_alipay('20190221225635096698')
    # # print query_alipay('20190223121236774713')
    # # print query_wxorder('20190223121236774713')
    out_trade_no = '20190225144618259000' #燃41 侯玉文
    # out_trade_no = '20190226044259187762' #数4 杨建科
    # # out_trade_no = '20190221164954776532'
    # # print query_alipay(out_trade_no)
    # # print query_wxorder(out_trade_no)
    # # print str2md5('HPPTESTPYTHONPROJECT:hpp.123456')
    # # get_order_tsinghua('test1')
    #
    # # query_order_tsinghua('tcdf100862201903050929598090003')
    ts = JYTSINGHUAPAY('2025', 'fb097338e13afb1f')
    print ts.down_bill({'t_item': 100862, 't_bill_date': '20190305'})
    # # print len(out_trade_no)
    # jy_wx = JYWX('wx78f7ae678bcfbfd1', 'f836cc553408bf9ff400e800deb41713')
    # print jy_wx.send_msg()



# -*- coding: utf-8 -*-
# !/usr/bin/python
# Create Date 2018/7/5 0005
__author__ = 'huohuo'
import os
if __name__ == "__main__":
    pass
    

def get_imgs(path):
    for i in os.listdir(path):
        path_file = os.path.join(path,i)
        if os.path.isfile(path_file):
            path_file1 = path_file.replace(' ', '_')
            os.rename(path_file, path_file1)
        else:
            get_imgs(path_file)


get_imgs('D:\pythonproject\\report\data')


#! /usr/bin/env python
# coding: utf-8
__author__ = 'huo'
import time
import requests

from jy_word.File import File
from jy_word.Word import Paragraph, Run, Set_page, Table, Tc, Tr, HyperLink
from jy_word.Word import uniq_list
import sys
reload(sys)
sys.setdefaultencoding('utf-8')

my_file = File()

r = Run()
hyperlink = HyperLink()
r.family_en = 'Times New Roman'
p = Paragraph()
set_page = Set_page().set_page
table = Table()
tr = Tr()
tc = Tc()
gray = 'E9E9E9'
gray_lighter = 'EEEEEE'
blue = '00ADEF'
white = 'FFFFFF'
red = 'ED1C24'
orange = 'F14623'
colors = ['2C3792', '3871C1', '50ADE5', '37AB9C', '27963C', '40B93C', '80CC28']


# 初号=42磅
# 小初=36磅
# 一号=26磅
# 小一=24磅
# 二号=22磅
# 小二=18磅
# 三号=16磅
# 小三=15磅
# 四号=14磅
# 小四=12磅
# 五号=10.5磅
# 小五=9磅
# 六号=7.5磅
# 小六=6.5磅
# 七号=5.5磅
# 八号=5磅


# ##################下载报告所需方法######################



def write_gene_list():
    gene_items = get_gene_list()
    items = []
    for i in range(len(gene_items)):
        gene = gene_items[i]
        print i+1, gene, len(gene_items), format_time()
        items.append(get_gene_info(gene))
        my_file.write('data/1.2gene_list.json', items)
    return items


def get_gene_list():
    db_table = my_file.read('0.2.2.variant_anno.maf.xls', sheet_name='0.2.2.variant_anno.maf', dict_name='data/part1')
    items = db_table.col_values(0)[1:]
    items = uniq_list(items)
    return items


def get_gene_info(gene):
    summary = ''
    description = ''
    url1 = 'http://oncokb.org/api/v1/evidences/lookup?hugoSymbol=%s&evidenceTypes=GENE_SUMMARY' % gene
    url2 = 'http://oncokb.org/api/v1/evidences/lookup?hugoSymbol=%s&evidenceTypes=GENE_BACKGROUND' % gene
    data1 = my_request(url1)
    data2 = my_request(url2)
    item = {'hugoSymbol': gene}
    if data2 is not None:
        if len(data2) > 0:
            info = data2[0]
            if 'gene' in info:
                gene_info = info['gene']
                item.update(gene_info)
            if 'description' in info:
                description = info['description']
    if data1 is not None:
        if len(data1) > 0:
            if 'description' in data1[0]:
                summary = data1[0]['description']
    item['summary'] = summary
    item['description'] = description
    return item


def get_evidence():
    items = []
    gene_items = []
    gene_list = []
    for level in ['1', '2A', '3A', '4']:
        url1 = 'http://oncokb.org/legacy-api/evidence.json?levels=LEVEL_%s' % level
        data1 = my_request(url1)
        if data1 is not None:
            print level, len(data1[0])
            items += data1[0]
            for item in data1[0]:
                gene = item['gene']['hugoSymbol']
                if gene not in gene_list:
                    gene_list.append(gene)
                    gene_items.append(get_gene_info(gene))
    my_file.write('oncokb_evidence_level.json', items)
    print len(gene_items)
    my_file.write('oncokb_gene_info.json', gene_items)
    # my_file.write('oncokb_evidence_level.xls', items)
    return items


def my_request(url, r='json'):
    try:
        rq = requests.get(url)
    except:
        return None
    if rq.status_code == 200:
        if r == 'json':
            data = rq.json()
            return data
        return rq.text
    return None


def format_time(t=None, frm="%Y-%m-%d %H:%M:%S"):
    if t is None:
        t = time.localtime()
    if type(t) == int:
        t = time.localtime(t)
    my_time = time.strftime(frm, t)
    return my_time



# write_gene_list()
# get_evidence()


print my_request('https://www.snpedia.com/index.php?title=Special:Ask&offset=0&limit=500&q=%5B%5BCategory%3AIs+a+genotype%5D%5D&p=mainlabel%3D%2Fformat%3Dtable&po=%3FMagnitude%0A%3FRepute%0A%3FSummary%0A&sort=magnitude&order=desc', 'text')


# -*- coding: utf-8 -*-
# !/usr/bin/python
# Create Date 2018/11/10 0010
__author__ = 'huohuo'
import os
pdf_path = '/tumor/facets_cval_50.pdf'
print os.path.exists(pdf_path)
import PythonMagick
p = 0

try:
    im =PythonMagick.Image(pdf_path)
    im.density('300') #设置dpi，不设置估计就96dpi
    im.read(pdf_path+ '[' + str(p) +']')
    im.write('file_out-'+ str(p)+ '.png')
except:
    print "PythonMagick 产生错误:"



# -*- coding: utf-8 -*-
# !/usr/bin/python
# Create Date 2018/7/30 0030
__author__ = 'huohuo'
import scipy.io
data = scipy.io.loadmat(r'D:\pythonproject\report\data\variant_anno.v2.maf')  # 读取mat文件
print(data.keys())   # 查看mat文件中的所有变量
print(data['matrix1'])
print(data['matrix2'])
matrix1 = data['matrix1']
matrix2 = data['matrix2']
print(matrix1)
print(matrix2)
# scipy.io.savemat('matData2.mat',{'matrix1':matrix1, 'matrix2':matrix2})  # 写入mat文件

if __name__ == "__main__":
    pass
    

